@@ -2,11 +2,11 @@ package ovn
 
 import (
 	"fmt"
-	"github.com/ovn-org/ovn-kubernetes/go-controller/pkg/config"
+	"net"
+
 	"github.com/ovn-org/ovn-kubernetes/go-controller/pkg/util"
 	"github.com/sirupsen/logrus"
 	kapi "k8s.io/api/core/v1"
-	"net"
 )
 
 func (ovn *Controller) syncServices(services []interface{}) {
@@ -64,7 +64,7 @@ func (ovn *Controller) syncServices(services []interface{}) {
 				continue
 			}
 
-			key := fmt.Sprintf("%s:%d", service.Spec.ClusterIP, svcPort.Port)
+			key := util.JoinHostPortInt32(service.Spec.ClusterIP, svcPort.Port)
 			if protocol == TCP {
 				clusterServices[TCP] = append(clusterServices[TCP], key)
 			} else {
@@ -75,7 +75,7 @@ func (ovn *Controller) syncServices(services []interface{}) {
 				continue
 			}
 			for _, extIP := range service.Spec.ExternalIPs {
-				key := fmt.Sprintf("%s:%d", extIP, svcPort.Port)
+				key := util.JoinHostPortInt32(extIP, svcPort.Port)
 				if protocol == TCP {
 					lbServices[TCP] = append(lbServices[TCP], key)
 				} else {
@@ -190,12 +190,12 @@ func (ovn *Controller) deleteService(service *kapi.Service) {
 
 		// targetPort can be anything, the deletion logic does not use it
 		var targetPort int32
-		if util.ServiceTypeHasNodePort(service) && config.Gateway.NodeportEnable {
+		if util.ServiceTypeHasNodePort(service) {
 			// Delete the 'NodePort' service from a load-balancer instantiated in gateways.
 			err := ovn.createGatewaysVIP(string(protocol), port, targetPort, ips)
 			if err != nil {
 				logrus.Errorf("Error in deleting NodePort gateway entry for service "+
-					"%s:%d %+v", service.Name, port, err)
+					"%s %+v", util.JoinHostPortInt32(service.Name, port), err)
 			}
 		}
 		if util.ServiceTypeHasClusterIP(service) {
@@ -210,7 +210,7 @@ func (ovn *Controller) deleteService(service *kapi.Service) {
 				service.Spec.ClusterIP, svcPort.Port, ips, targetPort)
 			if err != nil {
 				logrus.Errorf("Error in deleting load balancer for service "+
-					"%s:%d %+v", service.Name, port, err)
+					"%s %+v", util.JoinHostPortInt32(service.Name, port), err)
 			}
 			ovn.handleExternalIPs(service, svcPort, ips, targetPort)
 		}
